_positive = set(
    [
        "abba",
        "ability",
        "abovementioned",
        "absolute",
        "absolution",
        "absorbed",
        "abundant",
        "academic",
        "academy",
        "acceptable",
        "acceptance",
        "accessible",
        "accolade",
        "accommodation",
        "accompaniment",
        "accomplish",
        "accomplished",
        "accomplishment",
        "accord",
        "accountability",
        "accountable",
        "accredited",
        "accueil",
        "accurate",
        "ace",
        "achieve",
        "achievement",
        "acknowledgment",
        "acquire",
        "acquiring",
        "acrobat",
        "action",
        "actual",
        "acuity",
        "acumen",
        "adapt",
        "adaptable",
        "addresses",
        "adept",
        "adequacy",
        "adjunct",
        "admirable",
        "admiral",
        "admiration",
        "admire",
        "admirer",
        "admissible",
        "adorable",
        "adoration",
        "adore",
        "advance",
        "advanced",
        "advancement",
        "advantage",
        "advantageous",
        "advent",
        "adventure",
        "adventurous",
        "advisable",
        "advise",
        "adviser",
        "advocacy",
        "aesthetic",
        "aesthetics",
        "affable",
        "affection",
        "affiliated",
        "affirm",
        "affirmation",
        "affirmative",
        "affirmatively",
        "affluence",
        "affluent",
        "afford",
        "aga",
        "agile",
        "agility",
        "agree",
        "agreeable",
        "agreed",
        "agreeing",
        "agreement",
        "agriculture",
        "ahead",
        "aid",
        "aiding",
        "alabaster",
        "alertness",
        "alimentation",
        "alive",
        "allay",
        "allegiance",
        "allegro",
        "alleviate",
        "alleviation",
        "allied",
        "allowable",
        "allure",
        "alluring",
        "ally",
        "almighty",
        "aloha",
        "amazingly",
        "ambassador",
        "ambition",
        "ameliorate",
        "amen",
        "amenable",
        "amend",
        "amends",
        "amenity",
        "amiable",
        "amicable",
        "amnesty",
        "amour",
        "amuse",
        "amused",
        "amusement",
        "amusing",
        "analyst",
        "anchor",
        "anchorage",
        "angel",
        "angelic",
        "animate",
        "animated",
        "antibiotics",
        "antidote",
        "antifungal",
        "antique",
        "antiseptic",
        "aplomb",
        "apologetic",
        "apologize",
        "apology",
        "apostle",
        "applause",
        "appreciation",
        "approbation",
        "approval",
        "approve",
        "approving",
        "apt",
        "aptitude",
        "archaeology",
        "ardent",
        "ardor",
        "aristocracy",
        "aristocratic",
        "armor",
        "aroma",
        "arouse",
        "array",
        "art",
        "articulate",
        "articulation",
        "artisan",
        "artiste",
        "artistic",
        "ascendancy",
        "ascent",
        "aspiration",
        "aspire",
        "aspiring",
        "assembly",
        "assent",
        "asserting",
        "assets",
        "assist",
        "assistance",
        "associate",
        "assuage",
        "assurance",
        "assured",
        "astonishingly",
        "astonishment",
        "astrologer",
        "astronaut",
        "astronomer",
        "astute",
        "athlete",
        "athletic",
        "atom",
        "atone",
        "atonement",
        "attachment",
        "attainable",
        "attainment",
        "attendant",
        "attention",
        "attentive",
        "attest",
        "attorney",
        "attraction",
        "attractiveness",
        "augment",
        "august",
        "aunt",
        "aura",
        "auspicious",
        "authentic",
        "authenticity",
        "author",
        "authoritative",
        "authority",
        "authorization",
        "authorized",
        "avatar",
        "award",
        "ay",
        "aye",
        "baby",
        "baccalaureate",
        "backbone",
        "balance",
        "balanced",
        "ballad",
        "ballet",
        "ballot",
        "balsam",
        "banquet",
        "baptism",
        "baptismal",
        "bard",
        "bargain",
        "basketball",
        "bastion",
        "bath",
        "beam",
        "beaming",
        "beautification",
        "beautiful",
        "beautify",
        "beauty",
        "bedrock",
        "beer",
        "befitting",
        "befriend",
        "believing",
        "benefactor",
        "beneficial",
        "benefit",
        "benevolence",
        "benign",
        "berth",
        "betrothed",
        "betterment",
        "beverage",
        "biblical",
        "bilingual",
        "birth",
        "birthday",
        "blameless",
        "bless",
        "blessed",
        "blessing",
        "blessings",
        "bliss",
        "blissful",
        "bloodless",
        "bloom",
        "blossom",
        "bodyguard",
        "bold",
        "boldness",
        "bolster",
        "bonanza",
        "bonne",
        "bonus",
        "bookish",
        "bookshop",
        "boon",
        "bountiful",
        "bounty",
        "bouquet",
        "brains",
        "bravery",
        "breakfast",
        "bridal",
        "bride",
        "bridegroom",
        "bridesmaid",
        "brighten",
        "brightness",
        "brilliant",
        "brocade",
        "brother",
        "brotherhood",
        "brotherly",
        "buddy",
        "build",
        "building",
        "bulldog",
        "bulletproof",
        "buoy",
        "buss",
        "butler",
        "buttery",
        "buxom",
        "buzz",
        "cab",
        "cabinet",
        "cafe",
        "calculator",
        "calf",
        "calm",
        "canary",
        "candid",
        "candidate",
        "candied",
        "capitalist",
        "captain",
        "captivate",
        "captivating",
        "career",
        "careful",
        "carefully",
        "caress",
        "caretaker",
        "carol",
        "cascade",
        "cash",
        "categorical",
        "cater",
        "cathartic",
        "cathedral",
        "cautious",
        "cautiously",
        "celebrated",
        "celebrating",
        "celebration",
        "celestial",
        "center",
        "centurion",
        "cerebral",
        "ceremony",
        "certainty",
        "chairman",
        "chairwoman",
        "champion",
        "chant",
        "charger",
        "charitable",
        "charity",
        "charm",
        "charming",
        "chastity",
        "chattering",
        "checklist",
        "cheer",
        "cheerful",
        "cheerfulness",
        "cheering",
        "cheery",
        "chemist",
        "cherish",
        "cherry",
        "chieftain",
        "child",
        "childhood",
        "chirp",
        "chisel",
        "chivalry",
        "chocolate",
        "choice",
        "choir",
        "choral",
        "chorus",
        "chosen",
        "chowder",
        "chronicle",
        "chuckle",
        "church",
        "cider",
        "circumcision",
        "citizen",
        "civil",
        "civility",
        "civilization",
        "civilized",
        "clairvoyant",
        "clap",
        "clarify",
        "classic",
        "classical",
        "classics",
        "classify",
        "clean",
        "cleaning",
        "cleanliness",
        "cleanly",
        "cleanse",
        "cleansing",
        "clearance",
        "clearness",
        "clerical",
        "clever",
        "cleverness",
        "climax",
        "closeness",
        "closure",
        "clothe",
        "clown",
        "coalition",
        "coast",
        "coexist",
        "cogent",
        "cognitive",
        "coherence",
        "coherent",
        "cohesive",
        "collectively",
        "colonel",
        "colossal",
        "comfort",
        "commandant",
        "commanding",
        "commemorate",
        "commemoration",
        "commemorative",
        "commend",
        "commendable",
        "commentator",
        "committed",
        "commodore",
        "commonwealth",
        "communicate",
        "communicative",
        "communion",
        "community",
        "commutation",
        "commute",
        "companion",
        "compassion",
        "compassionate",
        "compatibility",
        "compatible",
        "compelling",
        "compensate",
        "compensatory",
        "competence",
        "competency",
        "competent",
        "complacency",
        "complement",
        "complementary",
        "completely",
        "completeness",
        "completing",
        "completion",
        "compliance",
        "compliant",
        "compliment",
        "composed",
        "composer",
        "composure",
        "comprehend",
        "comprehensive",
        "comrade",
        "concentric",
        "conciliation",
        "concluding",
        "concord",
        "concordance",
        "condolence",
        "condone",
        "conducive",
        "conductivity",
        "confederate",
        "confidence",
        "confident",
        "confirmed",
        "conformance",
        "congenial",
        "congratulatory",
        "congregation",
        "congruence",
        "connoisseur",
        "conscience",
        "conscientious",
        "consciousness",
        "consecration",
        "conservation",
        "conserve",
        "considerable",
        "considerate",
        "consistency",
        "console",
        "consonant",
        "constancy",
        "constant",
        "constitutional",
        "construct",
        "consummate",
        "contact",
        "contemplation",
        "content",
        "continue",
        "contour",
        "contribute",
        "contributor",
        "convenience",
        "convenient",
        "convent",
        "convention",
        "conversant",
        "conversational",
        "convert",
        "convince",
        "cool",
        "coolness",
        "cooperate",
        "cooperating",
        "cooperation",
        "cooperative",
        "core",
        "coronation",
        "corporation",
        "corporeal",
        "corrective",
        "correspondence",
        "corroborate",
        "cosmopolitan",
        "cosy",
        "council",
        "counsel",
        "counselor",
        "count",
        "countess",
        "courage",
        "courageous",
        "courteous",
        "courtesy",
        "courtship",
        "cove",
        "covenant",
        "cradle",
        "craft",
        "craftsman",
        "cream",
        "create",
        "creative",
        "credence",
        "credential",
        "credibility",
        "credible",
        "credit",
        "creditable",
        "credited",
        "crescendo",
        "critique",
        "crowning",
        "crucial",
        "crystal",
        "cuddle",
        "culinary",
        "culmination",
        "cultivate",
        "cultivated",
        "cultivation",
        "culture",
        "curable",
        "curiosity",
        "curl",
        "cushion",
        "customer",
        "cute",
        "cutters",
        "dame",
        "dance",
        "daring",
        "darling",
        "dashing",
        "daughter",
        "dawn",
        "deal",
        "dear",
        "debate",
        "decency",
        "decent",
        "declaratory",
        "dedication",
        "defend",
        "defended",
        "defender",
        "defending",
        "defense",
        "deference",
        "definitive",
        "degree",
        "delectable",
        "delegate",
        "deliberate",
        "delicious",
        "delight",
        "delighted",
        "delightful",
        "deliverance",
        "delivery",
        "democracy",
        "demonstrable",
        "demonstrative",
        "depth",
        "descriptive",
        "deserve",
        "deserved",
        "designer",
        "desirable",
        "desiring",
        "desirous",
        "destination",
        "detect",
        "detection",
        "determination",
        "determined",
        "develop",
        "devotional",
        "devout",
        "dexterity",
        "diamond",
        "diary",
        "dictionary",
        "didactic",
        "dietary",
        "dignified",
        "dignity",
        "diligence",
        "dinner",
        "diplomacy",
        "diplomatic",
        "director",
        "discovery",
        "discreet",
        "discretion",
        "discretionary",
        "discussion",
        "disinfection",
        "disposed",
        "disseminate",
        "distillation",
        "distinction",
        "ditty",
        "diversified",
        "diversion",
        "divinity",
        "doctor",
        "doer",
        "dogged",
        "dolphin",
        "don",
        "donation",
        "doubtless",
        "dove",
        "downy",
        "duet",
        "duke",
        "durability",
        "durable",
        "dutiful",
        "eager",
        "eagerness",
        "earl",
        "earn",
        "earnest",
        "earnestly",
        "earnestness",
        "ease",
        "easement",
        "easygoing",
        "eat",
        "ecstasy",
        "ecstatic",
        "edification",
        "educate",
        "educated",
        "educational",
        "effective",
        "efficacy",
        "efficiency",
        "efficient",
        "effort",
        "ejaculation",
        "elaboration",
        "elated",
        "elder",
        "elders",
        "elect",
        "electric",
        "electricity",
        "elegance",
        "elegant",
        "elevation",
        "eligible",
        "elite",
        "eloquence",
        "eloquent",
        "elucidate",
        "emancipation",
        "embrace",
        "emeritus",
        "eminence",
        "eminent",
        "eminently",
        "emir",
        "empathy",
        "empower",
        "emulate",
        "enable",
        "enablement",
        "enchant",
        "enchanted",
        "enchanting",
        "encore",
        "encourage",
        "encouragement",
        "encyclopedia",
        "endeavor",
        "endow",
        "endowed",
        "endowment",
        "endurance",
        "endure",
        "energetic",
        "engaged",
        "engaging",
        "enhance",
        "enjoy",
        "enjoying",
        "enlighten",
        "enlightenment",
        "enliven",
        "enrich",
        "ensemble",
        "ensign",
        "enterprising",
        "entertain",
        "entertained",
        "entertaining",
        "entertainment",
        "enthusiasm",
        "enthusiast",
        "environ",
        "ephemeris",
        "epic",
        "epitome",
        "equality",
        "equally",
        "equilibrium",
        "equity",
        "errand",
        "erudite",
        "esprit",
        "essential",
        "established",
        "esteem",
        "esthetic",
        "ethical",
        "ethics",
        "evergreen",
        "everlasting",
        "evident",
        "evolution",
        "exalt",
        "exaltation",
        "exalted",
        "exceed",
        "excel",
        "excellence",
        "excellent",
        "exchange",
        "excitable",
        "excitation",
        "excite",
        "excited",
        "excitement",
        "exciting",
        "exemplary",
        "exemption",
        "exhilaration",
        "exhort",
        "exhortation",
        "existence",
        "exotic",
        "expect",
        "expectation",
        "expedient",
        "expedition",
        "experienced",
        "expert",
        "expertise",
        "explain",
        "exquisite",
        "exquisitely",
        "extend",
        "extensive",
        "extra",
        "extraordinary",
        "extricate",
        "exuberance",
        "facilitate",
        "facts",
        "faculty",
        "fain",
        "fair",
        "fairly",
        "faith",
        "faithful",
        "fame",
        "familiar",
        "familiarity",
        "famous",
        "famously",
        "fancy",
        "fanfare",
        "fascinating",
        "fascination",
        "fashionable",
        "faultless",
        "favorable",
        "favorite",
        "favoritism",
        "fearless",
        "feat",
        "feature",
        "felicity",
        "fellow",
        "fellowship",
        "female",
        "fertile",
        "fervor",
        "festival",
        "festive",
        "fete",
        "fidelity",
        "fiesta",
        "finally",
        "finery",
        "finesse",
        "fireball",
        "fireproof",
        "firmness",
        "firstborn",
        "fitting",
        "fixture",
        "flattering",
        "fleet",
        "flexibility",
        "floral",
        "flow",
        "flowery",
        "flush",
        "flying",
        "focus",
        "fondness",
        "food",
        "football",
        "forbearance",
        "fore",
        "forefathers",
        "foregoing",
        "foreman",
        "forerunner",
        "foresee",
        "foreseen",
        "foresight",
        "forge",
        "forgive",
        "forgiven",
        "forgiving",
        "formative",
        "formula",
        "forte",
        "forthcoming",
        "fortify",
        "fortitude",
        "fortress",
        "fortunate",
        "fortune",
        "forward",
        "found",
        "foundation",
        "fragrant",
        "frank",
        "frankness",
        "fraternal",
        "freedom",
        "freely",
        "friend",
        "friendliness",
        "friendly",
        "friendship",
        "frisky",
        "frolic",
        "frugal",
        "fruitful",
        "fulfill",
        "fulfillment",
        "full",
        "fully",
        "fun",
        "fundamental",
        "fuse",
        "fusion",
        "gain",
        "gaining",
        "gallant",
        "gallantry",
        "galore",
        "garden",
        "garnet",
        "garrison",
        "gazette",
        "gear",
        "gem",
        "general",
        "generosity",
        "generous",
        "genial",
        "genius",
        "genteel",
        "gentleman",
        "gentleness",
        "gentry",
        "genuine",
        "geranium",
        "gift",
        "gifted",
        "gigantic",
        "giggle",
        "girder",
        "giving",
        "glad",
        "gladness",
        "glee",
        "glide",
        "glimmer",
        "glittering",
        "glorification",
        "glorify",
        "glory",
        "gloss",
        "glow",
        "glowing",
        "god",
        "godly",
        "godsend",
        "gold",
        "good",
        "goodly",
        "goodness",
        "goods",
        "goodwill",
        "gorgeous",
        "gospel",
        "govern",
        "grace",
        "graceful",
        "gracious",
        "graciously",
        "graduation",
        "grandchildren",
        "grandeur",
        "grandmother",
        "grant",
        "granted",
        "grateful",
        "gratify",
        "gratitude",
        "greater",
        "greatness",
        "green",
        "greeting",
        "gregarious",
        "grin",
        "grist",
        "grit",
        "groundwork",
        "grow",
        "growth",
        "guarantee",
        "guard",
        "guardian",
        "guardianship",
        "gubernatorial",
        "guidance",
        "guide",
        "guidebook",
        "guru",
        "guts",
        "gymnast",
        "habitat",
        "hale",
        "handy",
        "happily",
        "happiness",
        "happy",
        "hardy",
        "harmoniously",
        "harmony",
        "harvest",
        "haven",
        "headway",
        "heal",
        "healing",
        "healthful",
        "healthy",
        "heartfelt",
        "hearth",
        "heartily",
        "heavenly",
        "heavens",
        "heft",
        "helmet",
        "helper",
        "helpful",
        "herbal",
        "hero",
        "heroic",
        "heroics",
        "heroine",
        "heroism",
        "heyday",
        "hilarious",
        "hilarity",
        "hire",
        "hobby",
        "holiday",
        "holiness",
        "holy",
        "homage",
        "homology",
        "honest",
        "honesty",
        "honey",
        "honeymoon",
        "honor",
        "honorable",
        "hope",
        "hopeful",
        "horizon",
        "hospitality",
        "household",
        "housekeeping",
        "hug",
        "humane",
        "humanitarian",
        "humanity",
        "humbled",
        "humbly",
        "humility",
        "humorist",
        "humorous",
        "hurrah",
        "husbandry",
        "hush",
        "hut",
        "hygienic",
        "hymn",
        "idealism",
        "idol",
        "illuminate",
        "illumination",
        "illustrate",
        "illustrious",
        "imaginative",
        "immaculate",
        "immense",
        "immerse",
        "immortal",
        "impart",
        "impartial",
        "impartiality",
        "impeccable",
        "impervious",
        "importance",
        "important",
        "impress",
        "impression",
        "improve",
        "improved",
        "improvement",
        "improving",
        "improvise",
        "inalienable",
        "inauguration",
        "incisive",
        "include",
        "included",
        "including",
        "inclusive",
        "increase",
        "indelible",
        "indemnity",
        "independence",
        "indestructible",
        "individuality",
        "indomitable",
        "ineffable",
        "inexpensive",
        "infallible",
        "infant",
        "infinite",
        "infinity",
        "influential",
        "information",
        "ingenious",
        "inheritance",
        "inimitable",
        "innocence",
        "innocent",
        "innocently",
        "innocuous",
        "innovate",
        "innovation",
        "inquirer",
        "inquiry",
        "inquisitive",
        "inseparable",
        "insignia",
        "inspector",
        "inspiration",
        "inspire",
        "inspired",
        "instinctive",
        "instruct",
        "instruction",
        "instructor",
        "instrumental",
        "insure",
        "intact",
        "integrity",
        "intellect",
        "intellectual",
        "intelligence",
        "intelligent",
        "intended",
        "intercourse",
        "interest",
        "interested",
        "interesting",
        "interior",
        "interlocutory",
        "interlude",
        "intimate",
        "intonation",
        "intrepid",
        "intuition",
        "intuitive",
        "invariably",
        "inventive",
        "inventor",
        "investigate",
        "invigorate",
        "invitation",
        "invite",
        "inviting",
        "iron",
        "irreducible",
        "irrefutable",
        "jackpot",
        "jam",
        "jest",
        "job",
        "join",
        "joined",
        "joker",
        "joking",
        "journalist",
        "journey",
        "jovial",
        "joy",
        "joyful",
        "joyous",
        "jubilant",
        "jubilee",
        "judicial",
        "judicious",
        "jump",
        "justice",
        "justifiable",
        "justification",
        "keepsake",
        "ken",
        "keynote",
        "keystone",
        "kind",
        "kindness",
        "kindred",
        "king",
        "kiss",
        "kitten",
        "knack",
        "knight",
        "knowing",
        "knowledge",
        "kudos",
        "labor",
        "lamb",
        "land",
        "landed",
        "laser",
        "laudable",
        "laugh",
        "laughing",
        "laughter",
        "launch",
        "laureate",
        "laurel",
        "laurels",
        "lavish",
        "lawful",
        "lead",
        "leader",
        "league",
        "learn",
        "learning",
        "lecturer",
        "leeway",
        "legal",
        "legalized",
        "legendary",
        "legibility",
        "legible",
        "leisure",
        "leisurely",
        "lemma",
        "lenient",
        "lesson",
        "lettered",
        "level",
        "leverage",
        "liberate",
        "liberation",
        "liberty",
        "library",
        "lifeblood",
        "lighthouse",
        "liking",
        "linguist",
        "lion",
        "lithe",
        "logical",
        "longevity",
        "lordship",
        "lovable",
        "love",
        "lovely",
        "lovemaking",
        "lover",
        "loving",
        "loyal",
        "loyalty",
        "luck",
        "lucky",
        "luscious",
        "luster",
        "lustrous",
        "luxuriant",
        "luxurious",
        "luxury",
        "lyre",
        "lyrical",
        "magical",
        "magnet",
        "magnetism",
        "magnetite",
        "magnificence",
        "magnificent",
        "maiden",
        "main",
        "mainstay",
        "majestic",
        "majesty",
        "major",
        "majority",
        "manage",
        "management",
        "mandarin",
        "manhood",
        "manifested",
        "manly",
        "manna",
        "mannered",
        "manners",
        "manufacturer",
        "march",
        "marked",
        "marketable",
        "marquis",
        "marriage",
        "marrow",
        "marry",
        "marshal",
        "marvel",
        "marvelous",
        "marvelously",
        "masculine",
        "massage",
        "master",
        "masterpiece",
        "mastery",
        "mate",
        "matrimony",
        "matron",
        "maximum",
        "mayor",
        "meadow",
        "measured",
        "medal",
        "mediate",
        "mediation",
        "mediator",
        "medical",
        "meditate",
        "mediterranean",
        "medley",
        "memento",
        "memorable",
        "mending",
        "menses",
        "mentor",
        "merciful",
        "mercy",
        "merge",
        "merit",
        "meritorious",
        "merriment",
        "merry",
        "metropolitan",
        "mettle",
        "microscopy",
        "midwifery",
        "mighty",
        "mime",
        "mindful",
        "mindfulness",
        "ministry",
        "miracle",
        "miraculous",
        "mirth",
        "missionary",
        "model",
        "moderate",
        "moderator",
        "modest",
        "modesty",
        "momentum",
        "monetary",
        "money",
        "monk",
        "monument",
        "moral",
        "morality",
        "morals",
        "mortar",
        "motherhood",
        "motive",
        "movable",
        "mover",
        "muscular",
        "music",
        "musical",
        "mutable",
        "mutual",
        "nap",
        "naturalist",
        "navigable",
        "neatly",
        "nectar",
        "needle",
        "negotiate",
        "negotiator",
        "neighbor",
        "nerve",
        "nestle",
        "nobility",
        "noble",
        "nobleman",
        "nomination",
        "normality",
        "notable",
        "notables",
        "noted",
        "notion",
        "nourishment",
        "numbers",
        "nurse",
        "nursery",
        "nurture",
        "nutritious",
        "oak",
        "oasis",
        "oath",
        "obedience",
        "objective",
        "obliging",
        "observant",
        "obtainable",
        "obvious",
        "occupant",
        "occupation",
        "occupy",
        "offer",
        "officer",
        "offset",
        "offshoot",
        "omniscient",
        "openness",
        "opera",
        "opportune",
        "opportunity",
        "optimism",
        "optimist",
        "option",
        "optional",
        "oracle",
        "oration",
        "orchestra",
        "ordained",
        "orderly",
        "ordination",
        "organic",
        "organization",
        "organize",
        "organized",
        "orgasm",
        "originality",
        "ornamented",
        "ornate",
        "outcome",
        "outdo",
        "outward",
        "overjoyed",
        "overwhelming",
        "ownership",
        "pacific",
        "pad",
        "padding",
        "paddle",
        "palatable",
        "palliative",
        "panacea",
        "panache",
        "panier",
        "paprika",
        "paragon",
        "paramount",
        "pardon",
        "parentage",
        "parietal",
        "partake",
        "participation",
        "partner",
        "partnership",
        "passion",
        "passionate",
        "pastime",
        "pastor",
        "pastry",
        "pasture",
        "patent",
        "patience",
        "patient",
        "patriarchal",
        "patron",
        "patronage",
        "pay",
        "peace",
        "peaceable",
        "peaceful",
        "peacock",
        "peck",
        "peculiarity",
        "pedigree",
        "peerless",
        "penchant",
        "perceive",
        "perceptible",
        "perennial",
        "perfect",
        "perfection",
        "performer",
        "perk",
        "permission",
        "perpetuity",
        "persistence",
        "persistent",
        "personable",
        "pertinent",
        "pharmaceutical",
        "philanthropist",
        "philanthropy",
        "philosopher",
        "phoenix",
        "phonetic",
        "physician",
        "physics",
        "physiology",
        "physique",
        "pick",
        "picnic",
        "picturesque",
        "piety",
        "pill",
        "pillow",
        "pilot",
        "pinnacle",
        "pioneer",
        "pious",
        "pith",
        "pivot",
        "placid",
        "planning",
        "playful",
        "playground",
        "playhouse",
        "pleasant",
        "pleased",
        "pleasurable",
        "pledge",
        "plenary",
        "plentiful",
        "plexus",
        "plum",
        "plumb",
        "plush",
        "ply",
        "pointedly",
        "police",
        "policeman",
        "polish",
        "polished",
        "polite",
        "politeness",
        "politic",
        "pool",
        "pope",
        "popularity",
        "popularized",
        "population",
        "portable",
        "possess",
        "potable",
        "potency",
        "powerful",
        "powerfully",
        "practice",
        "practiced",
        "practise",
        "praise",
        "praised",
        "praiseworthy",
        "pray",
        "precaution",
        "precede",
        "precedence",
        "precious",
        "precise",
        "precision",
        "predilection",
        "predominant",
        "preeminent",
        "prefer",
        "premier",
        "premises",
        "prepare",
        "prepared",
        "prescient",
        "presence",
        "present",
        "presentable",
        "preservative",
        "preserve",
        "president",
        "prestige",
        "presto",
        "pretty",
        "prevail",
        "prevention",
        "priceless",
        "pride",
        "priest",
        "priesthood",
        "priestly",
        "primacy",
        "primary",
        "prime",
        "primer",
        "prince",
        "princely",
        "princess",
        "principal",
        "pristine",
        "privileged",
        "probity",
        "procedure",
        "procession",
        "proctor",
        "procure",
        "prodigious",
        "prodigy",
        "producer",
        "producing",
        "production",
        "productive",
        "productivity",
        "profession",
        "professional",
        "professor",
        "proficiency",
        "proficient",
        "profuse",
        "progress",
        "progression",
        "progressive",
        "prolific",
        "prominence",
        "prominently",
        "promise",
        "promising",
        "promotion",
        "prop",
        "proper",
        "prophet",
        "prophylactic",
        "proposition",
        "prospect",
        "prosper",
        "prosperity",
        "prosperous",
        "protect",
        "protecting",
        "protective",
        "protector",
        "proud",
        "prove",
        "proverbial",
        "provide",
        "providing",
        "prudence",
        "prudent",
        "psalm",
        "public",
        "pull",
        "pulpit",
        "punctual",
        "punctuality",
        "puppy",
        "purely",
        "purification",
        "purify",
        "purist",
        "purity",
        "purr",
        "quaint",
        "qualified",
        "qualifying",
        "quest",
        "question",
        "quickness",
        "quiescent",
        "quiet",
        "quinine",
        "radiance",
        "radiant",
        "radiate",
        "radio",
        "rapt",
        "rapture",
        "rational",
        "reader",
        "readily",
        "readiness",
        "reading",
        "reaffirm",
        "real",
        "reason",
        "reassurance",
        "reassure",
        "rebate",
        "recast",
        "received",
        "receiving",
        "recherche",
        "reciprocate",
        "reclamation",
        "recline",
        "recognizable",
        "recommend",
        "reconciliation",
        "reconsideration",
        "reconstruct",
        "reconstruction",
        "recorder",
        "recoup",
        "recovery",
        "recreation",
        "recreational",
        "rectify",
        "redemption",
        "redress",
        "refine",
        "refinement",
        "reform",
        "reformation",
        "reformer",
        "refreshing",
        "refurbish",
        "regal",
        "regent",
        "regularity",
        "regulate",
        "rehabilitate",
        "rehabilitation",
        "reimburse",
        "reimbursement",
        "reinforcement",
        "reinstate",
        "rejoice",
        "rejoicing",
        "rejuvenate",
        "rejuvenated",
        "relaxation",
        "relevant",
        "reliability",
        "reliable",
        "reliance",
        "relief",
        "relieving",
        "remake",
        "remarkable",
        "remarkably",
        "remedy",
        "remission",
        "remodel",
        "renaissance",
        "render",
        "renewal",
        "renovate",
        "renovation",
        "renown",
        "renowned",
        "reorganize",
        "reparation",
        "repay",
        "repent",
        "replenish",
        "replete",
        "reporter",
        "repose",
        "represented",
        "reproductive",
        "reputable",
        "rescue",
        "reserve",
        "resident",
        "resilient",
        "resistive",
        "resolutely",
        "resources",
        "respect",
        "respectability",
        "respectable",
        "respectful",
        "respecting",
        "respects",
        "respite",
        "resplendent",
        "responsible",
        "responsive",
        "rest",
        "restful",
        "restitution",
        "restorative",
        "restoring",
        "restraint",
        "resumption",
        "retention",
        "reunion",
        "revel",
        "revels",
        "revere",
        "reverence",
        "reverend",
        "reverie",
        "revise",
        "revival",
        "revolutionary",
        "reward",
        "rhythm",
        "rhythmical",
        "ribbon",
        "richness",
        "rider",
        "righteous",
        "rightful",
        "rightly",
        "ripe",
        "ripen",
        "rising",
        "riveting",
        "roadster",
        "robust",
        "rock",
        "rod",
        "rollicking",
        "romance",
        "romantic",
        "romanticism",
        "romp",
        "rooted",
        "rosy",
        "rota",
        "routine",
        "royalty",
        "rubric",
        "ruth",
        "safe",
        "safeguard",
        "sage",
        "saint",
        "saintly",
        "salary",
        "salient",
        "salutary",
        "salute",
        "salvation",
        "salve",
        "samurai",
        "sanctification",
        "sanctify",
        "sanctuary",
        "sanguine",
        "sanitary",
        "satin",
        "satisfactorily",
        "satisfied",
        "save",
        "savings",
        "savor",
        "savory",
        "savvy",
        "scholar",
        "scholarship",
        "scientific",
        "scientist",
        "scintilla",
        "score",
        "scribe",
        "script",
        "scrumptious",
        "sculpture",
        "sea",
        "seal",
        "seasoned",
        "secretariat",
        "seniority",
        "sensational",
        "sense",
        "sensibility",
        "sensibly",
        "sensuality",
        "sensuous",
        "sentimental",
        "sentimentality",
        "sentinel",
        "serenity",
        "sermon",
        "serum",
        "settlor",
        "sex",
        "shape",
        "shapely",
        "share",
        "shelter",
        "shepherd",
        "shine",
        "shining",
        "shopping",
        "shoulder",
        "shrewd",
        "silk",
        "simplify",
        "sincere",
        "sincerity",
        "sing",
        "singly",
        "sir",
        "sisterhood",
        "skilled",
        "skillful",
        "sky",
        "slate",
        "sleek",
        "slender",
        "slim",
        "smile",
        "smiling",
        "smitten",
        "smoothness",
        "snicker",
        "sobriety",
        "sociable",
        "solace",
        "soldier",
        "solid",
        "solidity",
        "solution",
        "solvency",
        "sonar",
        "sonata",
        "sonnet",
        "sonorous",
        "soothe",
        "soothing",
        "sorter",
        "soundness",
        "soup",
        "spa",
        "spacious",
        "spaniel",
        "sparkle",
        "special",
        "specie",
        "speech",
        "speedy",
        "spelling",
        "spice",
        "spirit",
        "spirits",
        "splendid",
        "splendor",
        "sponsor",
        "spotless",
        "spouse",
        "spruce",
        "stable",
        "staccato",
        "stainless",
        "stallion",
        "stalwart",
        "stamina",
        "standing",
        "star",
        "starlight",
        "starry",
        "stately",
        "statement",
        "statue",
        "status",
        "staunch",
        "steadfast",
        "stellar",
        "steward",
        "stillness",
        "store",
        "straightforward",
        "strategic",
        "strategist",
        "strength",
        "strengthen",
        "strengthening",
        "striking",
        "strikingly",
        "strongly",
        "structure",
        "stud",
        "study",
        "sturdy",
        "sublimation",
        "substance",
        "substantive",
        "succeed",
        "succeeding",
        "success",
        "successful",
        "succinct",
        "sufficiency",
        "sugar",
        "suitable",
        "sultry",
        "sun",
        "sunny",
        "sunset",
        "sunshine",
        "superb",
        "superhuman",
        "superior",
        "superiority",
        "superman",
        "superstar",
        "supplication",
        "supplies",
        "supply",
        "supported",
        "supporter",
        "supporting",
        "supreme",
        "supremely",
        "surety",
        "surmise",
        "surpassing",
        "surprise",
        "surveying",
        "survive",
        "swear",
        "sweet",
        "sweetheart",
        "sweetie",
        "sweetness",
        "sweets",
        "swift",
        "swim",
        "symbolic",
        "symmetrical",
        "symmetry",
        "sympathetic",
        "sympathy",
        "symphony",
        "synchronize",
        "synergistic",
        "synod",
        "tact",
        "tale",
        "talent",
        "talisman",
        "talk",
        "tanned",
        "task",
        "tasteful",
        "tasty",
        "teach",
        "teacher",
        "technology",
        "temperance",
        "tempered",
        "tenable",
        "tenacious",
        "tenacity",
        "tenancy",
        "tenant",
        "tender",
        "tenderness",
        "thankful",
        "thanksgiving",
        "theoretical",
        "therapeutic",
        "therapeutics",
        "thinker",
        "thoroughbred",
        "thoughtful",
        "thoughtfulness",
        "thrift",
        "thrill",
        "thrilling",
        "thriving",
        "throne",
        "tickle",
        "tiling",
        "timely",
        "tinsel",
        "title",
        "toast",
        "tolerant",
        "toleration",
        "top",
        "toughness",
        "tower",
        "towering",
        "traditional",
        "tranquil",
        "tranquility",
        "transcendence",
        "transcendental",
        "traveling",
        "treasure",
        "tree",
        "tremendously",
        "trend",
        "trendy",
        "tributary",
        "tribute",
        "trig",
        "triumph",
        "triumphant",
        "trophy",
        "truce",
        "True",
        "trusty",
        "truth",
        "truthfulness",
        "tutelage",
        "tutor",
        "twin",
        "twinkle",
        "ultimately",
        "umpire",
        "unanimity",
        "unanimous",
        "unassuming",
        "unbiased",
        "unbreakable",
        "unbroken",
        "unconstrained",
        "underline",
        "understanding",
        "underwrite",
        "undivided",
        "undying",
        "unequivocally",
        "unfold",
        "unification",
        "uniformly",
        "uninfected",
        "unique",
        "unison",
        "unitary",
        "united",
        "unity",
        "university",
        "unlimited",
        "unpretentious",
        "unquestionable",
        "unquestionably",
        "unquestioned",
        "unscathed",
        "unselfish",
        "unsurpassed",
        "unwavering",
        "uplift",
        "upright",
        "usefulness",
        "usher",
        "usual",
        "utility",
        "utopian",
        "vacation",
        "vaccine",
        "valiant",
        "valor",
        "valuable",
        "vanguard",
        "vanquish",
        "velvet",
        "velvety",
        "venerable",
        "veneration",
        "veracity",
        "verdant",
        "verification",
        "verified",
        "verily",
        "veritable",
        "vernal",
        "verve",
        "veteran",
        "vicar",
        "victor",
        "victorious",
        "victory",
        "vigilance",
        "vigilant",
        "vigor",
        "vigorous",
        "villager",
        "vindicated",
        "vindication",
        "virgin",
        "virginity",
        "virtue",
        "virtuous",
        "vision",
        "visionary",
        "visit",
        "visitor",
        "vital",
        "vitality",
        "vivacious",
        "vivid",
        "vocabulary",
        "volunteer",
        "voluptuous",
        "vouch",
        "vow",
        "wages",
        "warranty",
        "warrior",
        "watchdog",
        "watchful",
        "watchman",
        "waterproof",
        "wealth",
        "weatherproof",
        "welcomed",
        "white",
        "whiteness",
        "wholesome",
        "wicket",
        "widespread",
        "willingly",
        "willingness",
        "windfall",
        "winner",
        "winning",
        "winnings",
        "wireless",
        "wis",
        "wisdom",
        "wise",
        "wit",
        "withstand",
        "wits",
        "witty",
        "wizard",
        "womb",
        "wonderful",
        "wonderfully",
        "wondrous",
        "word",
        "working",
        "worship",
        "worth",
        "worthy",
        "wot",
        "writer",
        "young",
        "younger",
        "youth",
        "zeal",
        "zealous",
        "zest",
    ]
)

_negative = set(
    [
        "abandon",
        "abandoned",
        "abandonment",
        "abduction",
        "aberrant",
        "aberration",
        "abhor",
        "abhorrent",
        "abject",
        "abnormal",
        "abolish",
        "abolition",
        "abominable",
        "abomination",
        "abort",
        "abortion",
        "abortive",
        "abrasion",
        "abrogate",
        "abscess",
        "absence",
        "absent",
        "absentee",
        "absenteeism",
        "absurd",
        "absurdity",
        "abuse",
        "abysmal",
        "abyss",
        "accident",
        "accidental",
        "accursed",
        "accusation",
        "accusative",
        "accused",
        "accuser",
        "accusing",
        "ache",
        "aching",
        "acid",
        "actionable",
        "adder",
        "addiction",
        "adipose",
        "adjudicate",
        "admonition",
        "adrift",
        "adulterated",
        "adultery",
        "adversary",
        "adverse",
        "adversity",
        "afflict",
        "afflicted",
        "affliction",
        "affront",
        "afraid",
        "aftermath",
        "aftertaste",
        "aggravated",
        "aggravating",
        "aggravation",
        "aggression",
        "aggressive",
        "aggressor",
        "aghast",
        "agitated",
        "agitation",
        "agonizing",
        "agony",
        "aground",
        "ail",
        "ailing",
        "aimless",
        "airs",
        "alarm",
        "alarming",
        "alcoholism",
        "alien",
        "alienate",
        "alienated",
        "alienation",
        "alimony",
        "allegation",
        "allege",
        "aloof",
        "altercation",
        "ambiguous",
        "ambush",
        "amnesia",
        "amphetamines",
        "anaconda",
        "anal",
        "anarchism",
        "anarchist",
        "anarchy",
        "anathema",
        "ancient",
        "anger",
        "angina",
        "angling",
        "angry",
        "anguish",
        "animosity",
        "animus",
        "annihilate",
        "annihilated",
        "annihilation",
        "annoy",
        "annoyance",
        "annoying",
        "annul",
        "annulment",
        "anomaly",
        "anonymous",
        "antagonism",
        "antagonist",
        "antagonistic",
        "anthrax",
        "antichrist",
        "antipathy",
        "antiquated",
        "antisocial",
        "antithesis",
        "anxiety",
        "anxious",
        "apache",
        "apathetic",
        "apathy",
        "aphid",
        "appalling",
        "appendicitis",
        "apprehension",
        "apprehensive",
        "appropriation",
        "archaic",
        "arduous",
        "argue",
        "argument",
        "argumentative",
        "arid",
        "armaments",
        "arraignment",
        "arrears",
        "arrest",
        "arrogance",
        "arrogant",
        "arsenic",
        "arson",
        "artillery",
        "ash",
        "ashamed",
        "ashes",
        "ass",
        "assail",
        "assailant",
        "assassin",
        "assassinate",
        "assassination",
        "assault",
        "asshole",
        "astray",
        "astringent",
        "asylum",
        "atheism",
        "atherosclerosis",
        "atrocious",
        "atrocity",
        "atrophy",
        "attack",
        "attacking",
        "attenuated",
        "attenuation",
        "audacity",
        "austere",
        "austerity",
        "autocratic",
        "autopsy",
        "avalanche",
        "avarice",
        "avenger",
        "averse",
        "aversion",
        "avoid",
        "avoidance",
        "awful",
        "awkwardness",
        "awry",
        "babble",
        "babbling",
        "baboon",
        "backward",
        "backwards",
        "backwater",
        "bacteria",
        "bacterium",
        "bad",
        "badger",
        "badly",
        "badness",
        "bailiff",
        "bait",
        "bale",
        "balk",
        "ban",
        "bandit",
        "bane",
        "bang",
        "banger",
        "banish",
        "banished",
        "banishment",
        "bankrupt",
        "bankruptcy",
        "banshee",
        "barb",
        "barbarian",
        "barbaric",
        "barbarism",
        "bark",
        "barred",
        "barren",
        "barricade",
        "barrier",
        "baseless",
        "bastard",
        "batter",
        "battered",
        "battery",
        "battle",
        "battled",
        "battlefield",
        "bawdy",
        "bayonet",
        "bearer",
        "beast",
        "beastly",
        "beating",
        "befall",
        "beg",
        "beggar",
        "begging",
        "behemoth",
        "beholden",
        "belated",
        "belittle",
        "belligerent",
        "belt",
        "bender",
        "bereaved",
        "bereavement",
        "bereft",
        "berserk",
        "bestial",
        "betray",
        "betrayal",
        "beware",
        "bewildered",
        "bias",
        "biased",
        "bickering",
        "bier",
        "bigot",
        "bigoted",
        "bile",
        "biopsy",
        "birch",
        "birthplace",
        "bitch",
        "bite",
        "bitterly",
        "bitterness",
        "bizarre",
        "black",
        "blackjack",
        "blackmail",
        "blackness",
        "blame",
        "bland",
        "blasphemous",
        "blasphemy",
        "blast",
        "blatant",
        "blather",
        "blaze",
        "bleak",
        "bleeding",
        "blemish",
        "blight",
        "blighted",
        "blind",
        "blinded",
        "blindly",
        "blindness",
        "blister",
        "bloated",
        "blob",
        "blockade",
        "bloodshed",
        "bloodthirsty",
        "bloody",
        "blot",
        "blower",
        "blowout",
        "blues",
        "bluff",
        "blunder",
        "blur",
        "blurred",
        "blush",
        "boasting",
        "bog",
        "bogus",
        "boil",
        "boilerplate",
        "bomb",
        "bombard",
        "bombardment",
        "bombed",
        "bondage",
        "bonds",
        "boo",
        "booby",
        "booze",
        "bore",
        "boredom",
        "boring",
        "borrower",
        "bother",
        "bothering",
        "bottom",
        "bound",
        "bout",
        "bovine",
        "boy",
        "boycott",
        "brag",
        "brandy",
        "bravado",
        "brawl",
        "brazen",
        "breach",
        "breakdown",
        "breakneck",
        "breakup",
        "bribe",
        "bribery",
        "brigade",
        "brimstone",
        "bristle",
        "broadside",
        "broil",
        "broke",
        "broken",
        "brothel",
        "bruise",
        "brunt",
        "brutal",
        "brutality",
        "brute",
        "buffet",
        "bug",
        "bugaboo",
        "bulbous",
        "bully",
        "bum",
        "bummer",
        "burdensome",
        "bureaucracy",
        "bureaucrat",
        "burglar",
        "burglary",
        "burial",
        "buried",
        "burke",
        "burnt",
        "busted",
        "butcher",
        "butt",
        "buzzed",
        "cabal",
        "cacophony",
        "cad",
        "cadaver",
        "cage",
        "calculating",
        "callous",
        "calls",
        "campaigning",
        "cancel",
        "cancer",
        "canker",
        "cannibal",
        "cannibalism",
        "cannon",
        "captive",
        "captivity",
        "captor",
        "capture",
        "carcass",
        "carcinoma",
        "cardiomyopathy",
        "carelessness",
        "caricature",
        "caries",
        "carnage",
        "carnal",
        "carnivorous",
        "cartel",
        "case",
        "casket",
        "caste",
        "casualty",
        "cataract",
        "catastrophe",
        "catheter",
        "caution",
        "cede",
        "cemetery",
        "censor",
        "censure",
        "cess",
        "cessation",
        "chaff",
        "chafing",
        "chagrin",
        "challenge",
        "chaos",
        "chaotic",
        "charade",
        "chargeable",
        "chase",
        "chastisement",
        "chatty",
        "cheap",
        "cheat",
        "cheesecake",
        "chicane",
        "childish",
        "chilly",
        "chloroform",
        "choke",
        "cholera",
        "chop",
        "chore",
        "chronic",
        "cigarette",
        "clamor",
        "clash",
        "clashing",
        "claw",
        "cloister",
        "clouded",
        "cloudiness",
        "clump",
        "clumsy",
        "cocaine",
        "coerce",
        "coercion",
        "coffin",
        "cold",
        "coldly",
        "coldness",
        "colic",
        "collapse",
        "collision",
        "collusion",
        "coma",
        "comatose",
        "combat",
        "combatant",
        "combative",
        "committal",
        "commotion",
        "communism",
        "communist",
        "competition",
        "complain",
        "complaint",
        "complexed",
        "complexity",
        "complicate",
        "complicated",
        "complication",
        "compost",
        "compulsion",
        "compulsory",
        "conceal",
        "concealed",
        "concealment",
        "conceit",
        "conceited",
        "concussion",
        "condemn",
        "condemnation",
        "condescending",
        "condescension",
        "confession",
        "confine",
        "confined",
        "confinement",
        "confiscate",
        "confiscation",
        "conflagration",
        "conflict",
        "conflicting",
        "confound",
        "confounded",
        "confuse",
        "confusion",
        "congestion",
        "conjuring",
        "conquest",
        "conspirator",
        "conspire",
        "consternation",
        "constipation",
        "constrain",
        "constrained",
        "constraint",
        "contagion",
        "contagious",
        "contaminate",
        "contaminated",
        "contamination",
        "contempt",
        "contemptible",
        "contemptuous",
        "contentious",
        "contraband",
        "contracted",
        "contradict",
        "contradiction",
        "contradictory",
        "contrary",
        "contrasted",
        "contravene",
        "contravention",
        "controversial",
        "controversy",
        "convict",
        "conviction",
        "coop",
        "copy",
        "copycat",
        "coroner",
        "corporal",
        "corpse",
        "correction",
        "corrosion",
        "corrosive",
        "corrupt",
        "corrupting",
        "corruption",
        "cough",
        "counsellor",
        "coursing",
        "covet",
        "coward",
        "cowardice",
        "cowardly",
        "crabby",
        "crack",
        "cracked",
        "cracking",
        "cramp",
        "cramped",
        "crank",
        "cranky",
        "crap",
        "crash",
        "crawl",
        "crazed",
        "crazy",
        "creaking",
        "creature",
        "creep",
        "crime",
        "criminal",
        "criminality",
        "cringe",
        "cripple",
        "crippled",
        "crisis",
        "crisp",
        "critic",
        "criticism",
        "criticize",
        "crook",
        "cross",
        "crouching",
        "cruciate",
        "crucifixion",
        "crude",
        "cruel",
        "cruelly",
        "cruelty",
        "crumbling",
        "crunch",
        "crusade",
        "crushed",
        "crushing",
        "crusty",
        "cry",
        "crying",
        "crypt",
        "cuckold",
        "cuckoo",
        "cull",
        "culpability",
        "culpable",
        "culprit",
        "cult",
        "cumbersome",
        "cupping",
        "cur",
        "curse",
        "cursed",
        "cursing",
        "cursory",
        "cutter",
        "cutthroat",
        "cutting",
        "cyanide",
        "cyclone",
        "cyst",
        "cytomegalovirus",
        "dabbling",
        "daemon",
        "daft",
        "dagger",
        "damage",
        "damages",
        "damn",
        "damnation",
        "damned",
        "damper",
        "dandruff",
        "dandy",
        "danger",
        "dangerous",
        "darken",
        "darkened",
        "darkness",
        "dashed",
        "dastardly",
        "dazed",
        "deactivate",
        "deadlock",
        "deadly",
        "deaf",
        "death",
        "debacle",
        "debauchery",
        "debris",
        "debt",
        "debtor",
        "decay",
        "decayed",
        "deceased",
        "deceit",
        "deceitful",
        "deceive",
        "deceived",
        "deceiving",
        "deception",
        "deceptive",
        "declination",
        "decline",
        "declining",
        "decomposition",
        "decrease",
        "decrement",
        "decrepit",
        "decry",
        "deduct",
        "defamation",
        "defamatory",
        "default",
        "defeat",
        "defeated",
        "defect",
        "defection",
        "defective",
        "defenseless",
        "deferral",
        "defiance",
        "defiant",
        "deficiency",
        "deficit",
        "deflate",
        "deflation",
        "deform",
        "deformed",
        "deformity",
        "defraud",
        "defunct",
        "defy",
        "degeneracy",
        "degenerate",
        "degradation",
        "degrade",
        "degrading",
        "delay",
        "delayed",
        "deleterious",
        "deletion",
        "delinquency",
        "delinquent",
        "delirious",
        "delirium",
        "deluge",
        "delusion",
        "delusional",
        "demand",
        "demanding",
        "demented",
        "dementia",
        "demise",
        "demolish",
        "demolition",
        "demon",
        "demonic",
        "demoralized",
        "denial",
        "denied",
        "denounce",
        "denunciation",
        "deny",
        "denying",
        "departed",
        "departure",
        "dependence",
        "dependency",
        "deplorable",
        "deplore",
        "deport",
        "deportation",
        "depraved",
        "depravity",
        "depreciate",
        "depreciated",
        "depreciation",
        "depress",
        "depressed",
        "depressing",
        "depression",
        "depressive",
        "deprivation",
        "deranged",
        "derelict",
        "derision",
        "derogation",
        "derogatory",
        "desecration",
        "desert",
        "deserted",
        "desertion",
        "desist",
        "desolation",
        "despair",
        "despairing",
        "desperate",
        "despicable",
        "despise",
        "despotic",
        "despotism",
        "destitute",
        "destroyed",
        "destroyer",
        "destroying",
        "destruction",
        "destructive",
        "detachment",
        "detain",
        "detainee",
        "detention",
        "deteriorate",
        "deteriorated",
        "deterioration",
        "detest",
        "detonate",
        "detract",
        "detriment",
        "detrimental",
        "detritus",
        "devastate",
        "devastating",
        "devastation",
        "devil",
        "devilish",
        "devious",
        "devolution",
        "devour",
        "diabolical",
        "diagnosis",
        "diatribe",
        "dictator",
        "dictatorial",
        "dictatorship",
        "die",
        "difficulties",
        "difficulty",
        "digress",
        "dilapidated",
        "dilute",
        "diminish",
        "diminished",
        "din",
        "dire",
        "dirt",
        "dirty",
        "disability",
        "disable",
        "disabled",
        "disaffected",
        "disagree",
        "disagreeing",
        "disagreement",
        "disallowed",
        "disappoint",
        "disappointed",
        "disappointing",
        "disappointment",
        "disapproval",
        "disapprove",
        "disapproved",
        "disapproving",
        "disaster",
        "disastrous",
        "disbelieve",
        "discards",
        "discharge",
        "discipline",
        "disclaim",
        "discoloration",
        "discolored",
        "discomfort",
        "disconnect",
        "disconnected",
        "disconnection",
        "discontent",
        "discontinue",
        "discontinuity",
        "discord",
        "discourage",
        "discouragement",
        "discredit",
        "discriminate",
        "discriminating",
        "discrimination",
        "disdain",
        "disease",
        "diseased",
        "disembodied",
        "disengagement",
        "disfigured",
        "disgrace",
        "disgraced",
        "disgraceful",
        "disgruntled",
        "disgust",
        "disgusting",
        "disheartened",
        "disheartening",
        "dishonest",
        "dishonesty",
        "dishonor",
        "disillusionment",
        "disinformation",
        "disingenuous",
        "disintegrate",
        "disintegration",
        "disinterested",
        "dislike",
        "disliked",
        "dislocated",
        "dismal",
        "dismay",
        "dismemberment",
        "dismissal",
        "disobedience",
        "disobedient",
        "disobey",
        "disorder",
        "disorderly",
        "disorganized",
        "disparage",
        "disparaging",
        "disparity",
        "dispassionate",
        "dispel",
        "dispersion",
        "displace",
        "displeased",
        "displeasure",
        "disposal",
        "dispossessed",
        "dispute",
        "disqualification",
        "disqualified",
        "disqualify",
        "disregard",
        "disregarded",
        "disreputable",
        "disrespect",
        "disrespectful",
        "disruption",
        "dissatisfaction",
        "dissension",
        "dissenting",
        "disservice",
        "dissident",
        "dissolution",
        "dissonance",
        "distaste",
        "distasteful",
        "distorted",
        "distortion",
        "distract",
        "distracted",
        "distracting",
        "distraction",
        "distraught",
        "distress",
        "distressed",
        "distressing",
        "distrust",
        "disturbance",
        "disturbed",
        "disuse",
        "disused",
        "divergent",
        "divested",
        "divestment",
        "divorce",
        "dizziness",
        "dizzy",
        "docked",
        "doit",
        "doldrums",
        "dole",
        "dolor",
        "dominant",
        "domination",
        "donkey",
        "doodle",
        "doom",
        "doomed",
        "doomsday",
        "doubt",
        "doubtful",
        "doubting",
        "douche",
        "dour",
        "downfall",
        "drab",
        "drainage",
        "drawback",
        "dread",
        "dreadful",
        "dreadfully",
        "dreary",
        "drinking",
        "drivel",
        "drone",
        "drooping",
        "drought",
        "drown",
        "drowsiness",
        "drudgery",
        "drunken",
        "drunkenness",
        "dubious",
        "dull",
        "dumb",
        "dummy",
        "dumps",
        "dun",
        "dungeon",
        "dupe",
        "duplicity",
        "duress",
        "dust",
        "dwarfed",
        "dying",
        "dysentery",
        "earthquake",
        "eavesdropping",
        "edict",
        "effeminate",
        "egotistical",
        "egregious",
        "eject",
        "ejection",
        "elimination",
        "elusive",
        "emaciated",
        "embargo",
        "embarrass",
        "embarrassing",
        "embarrassment",
        "embezzlement",
        "embolism",
        "embroiled",
        "emergency",
        "enclave",
        "encroachment",
        "encumbrance",
        "endanger",
        "endangered",
        "endemic",
        "enemy",
        "enforcement",
        "enigmatic",
        "enmity",
        "enslave",
        "enslaved",
        "enslavement",
        "entangled",
        "entanglement",
        "entrails",
        "envious",
        "epidemic",
        "epilepsy",
        "eradicate",
        "eradication",
        "erase",
        "erosion",
        "err",
        "errant",
        "erratic",
        "erratum",
        "erroneous",
        "error",
        "erupt",
        "eruption",
        "escalate",
        "eschew",
        "espionage",
        "estranged",
        "euthanasia",
        "evacuate",
        "evacuation",
        "evade",
        "evasion",
        "evict",
        "eviction",
        "evil",
        "exacerbate",
        "exacerbation",
        "exacting",
        "exaggerate",
        "exaggerated",
        "examination",
        "exasperation",
        "excavation",
        "excess",
        "excise",
        "excluded",
        "excluding",
        "exclusion",
        "excrement",
        "excruciating",
        "excuse",
        "execution",
        "executioner",
        "exhaust",
        "exhausted",
        "exhaustion",
        "exigent",
        "exile",
        "exorcism",
        "expatriate",
        "expel",
        "expenditure",
        "expenses",
        "expire",
        "expired",
        "expletive",
        "explode",
        "explosion",
        "explosive",
        "exposed",
        "expropriation",
        "expulsion",
        "exterminate",
        "extermination",
        "extinct",
        "extinguish",
        "extrajudicial",
        "extremity",
        "fabricate",
        "fabrication",
        "fade",
        "faeces",
        "failing",
        "failure",
        "fainting",
        "faithless",
        "fake",
        "fall",
        "fallacious",
        "fallacy",
        "fallible",
        "falling",
        "fallow",
        "falsehood",
        "falsely",
        "falsification",
        "falsify",
        "falsity",
        "falter",
        "famine",
        "fanatic",
        "farce",
        "farcical",
        "fasting",
        "fat",
        "fatal",
        "fatality",
        "fate",
        "fatigue",
        "fatigued",
        "fatty",
        "fault",
        "faulty",
        "fawn",
        "fear",
        "fearful",
        "fearfully",
        "fearing",
        "febrile",
        "fecal",
        "feces",
        "fee",
        "feeble",
        "feigned",
        "fell",
        "felon",
        "felony",
        "ferment",
        "ferocious",
        "ferocity",
        "feud",
        "feudal",
        "feudalism",
        "feverish",
        "fiasco",
        "fib",
        "fickle",
        "fictitious",
        "fiend",
        "fierce",
        "fight",
        "fighting",
        "filibuster",
        "filth",
        "filthy",
        "firearms",
        "fits",
        "flabby",
        "flaccid",
        "flagging",
        "flagrant",
        "flake",
        "flap",
        "flatulence",
        "flaunt",
        "flaw",
        "flea",
        "flee",
        "fleece",
        "fleshy",
        "flinch",
        "flog",
        "flop",
        "flounder",
        "flu",
        "fluctuation",
        "foe",
        "foiled",
        "folly",
        "fool",
        "foolish",
        "foolishness",
        "forage",
        "foray",
        "forbid",
        "forbidding",
        "force",
        "forced",
        "forcibly",
        "foreboding",
        "foreclose",
        "forego",
        "foreign",
        "foreigner",
        "forewarned",
        "forfeit",
        "forfeited",
        "forfeiture",
        "forgery",
        "forget",
        "forgotten",
        "forlorn",
        "formless",
        "fornication",
        "forsake",
        "forsaken",
        "foul",
        "fracture",
        "fragile",
        "frailty",
        "frantic",
        "fraud",
        "fraudulent",
        "fraught",
        "fray",
        "frayed",
        "freakish",
        "freezing",
        "frenetic",
        "frenzied",
        "frenzy",
        "fret",
        "fright",
        "frighten",
        "frightened",
        "frightful",
        "frigid",
        "frivolous",
        "frostbite",
        "froth",
        "frown",
        "frowning",
        "fruitless",
        "frustrate",
        "frustrated",
        "frustration",
        "fudge",
        "fugitive",
        "fumble",
        "fume",
        "fuming",
        "fungus",
        "funk",
        "furious",
        "furor",
        "fury",
        "fuss",
        "fussy",
        "futile",
        "futility",
        "gaby",
        "gag",
        "gall",
        "gallows",
        "gamble",
        "gambler",
        "gambling",
        "gang",
        "gaol",
        "gap",
        "garbage",
        "garish",
        "garnish",
        "gash",
        "gasping",
        "gauche",
        "gaunt",
        "gent",
        "geriatric",
        "ghastly",
        "ghetto",
        "ghostly",
        "gibberish",
        "glacial",
        "glare",
        "glaring",
        "glib",
        "gloom",
        "gloomy",
        "glum",
        "glut",
        "gluttony",
        "gnome",
        "goblin",
        "godless",
        "gonorrhea",
        "goo",
        "gore",
        "gorge",
        "gorilla",
        "gory",
        "gossip",
        "gouge",
        "gout",
        "government",
        "grab",
        "grasping",
        "grate",
        "grated",
        "grating",
        "grave",
        "greed",
        "greedy",
        "grenade",
        "grief",
        "grievance",
        "grieve",
        "grievous",
        "grim",
        "grime",
        "grimy",
        "grinding",
        "grisly",
        "grizzly",
        "groan",
        "grope",
        "gross",
        "grotesque",
        "grounded",
        "groundless",
        "growl",
        "growling",
        "grudge",
        "grudgingly",
        "gruesome",
        "gruff",
        "grumble",
        "grumpy",
        "guerilla",
        "guile",
        "guillotine",
        "guilt",
        "guilty",
        "guise",
        "gull",
        "gullible",
        "gun",
        "gush",
        "guzzling",
        "gypsy",
        "hag",
        "haggard",
        "hairy",
        "halfway",
        "hallucination",
        "halter",
        "halting",
        "hamper",
        "hamstring",
        "handicap",
        "hanging",
        "hangman",
        "harass",
        "harbinger",
        "hardened",
        "hardness",
        "hardship",
        "harlot",
        "harm",
        "harmful",
        "harrowing",
        "harry",
        "harshness",
        "hash",
        "hashish",
        "hasty",
        "hate",
        "hateful",
        "hating",
        "hatred",
        "haughty",
        "haunt",
        "haunted",
        "havoc",
        "hazard",
        "hazardous",
        "haze",
        "headache",
        "heady",
        "hearing",
        "hearsay",
        "hearse",
        "heartache",
        "heartburn",
        "heartless",
        "heathen",
        "heavily",
        "heel",
        "heighten",
        "heinous",
        "hell",
        "hellish",
        "helpless",
        "helplessness",
        "hemorrhage",
        "hemorrhoids",
        "heresy",
        "heretic",
        "hermaphrodite",
        "heroin",
        "herpes",
        "herpesvirus",
        "hesitation",
        "hidden",
        "hideous",
        "hindering",
        "hindrance",
        "hippie",
        "hiss",
        "hissing",
        "hit",
        "hitherto",
        "hive",
        "hoarse",
        "hoary",
        "hoax",
        "hobo",
        "hog",
        "hollow",
        "holocaust",
        "homeless",
        "homesick",
        "homicidal",
        "homicide",
        "homosexuality",
        "hood",
        "hooked",
        "hoot",
        "hopeless",
        "hopelessness",
        "horde",
        "horrible",
        "horribly",
        "horrid",
        "horrific",
        "horrified",
        "horrifying",
        "horror",
        "horrors",
        "hostage",
        "hostile",
        "hostilities",
        "hostility",
        "howl",
        "huff",
        "humbug",
        "humiliate",
        "humiliating",
        "humiliation",
        "hunch",
        "hungry",
        "hunter",
        "hunting",
        "hurricane",
        "hurried",
        "hurt",
        "hurtful",
        "hurting",
        "hustler",
        "hydra",
        "hydrocephalus",
        "hype",
        "hyperbole",
        "hypocrisy",
        "hypocrite",
        "hypocritical",
        "hysteria",
        "hysterical",
        "idiocy",
        "idiot",
        "idiotic",
        "idler",
        "idolatry",
        "ignorance",
        "ignorant",
        "ignore",
        "ill",
        "illegal",
        "illegality",
        "illegible",
        "illegitimate",
        "illicit",
        "illiterate",
        "illness",
        "illogical",
        "illusion",
        "imitated",
        "imitation",
        "immature",
        "immaturity",
        "immoral",
        "immorality",
        "impair",
        "impairment",
        "impassable",
        "impatience",
        "impatient",
        "impeach",
        "impeachment",
        "impede",
        "imperfection",
        "imperfectly",
        "impersonate",
        "impersonation",
        "implacable",
        "implicate",
        "impolite",
        "imposition",
        "impossible",
        "impotence",
        "impotent",
        "impound",
        "impracticable",
        "imprison",
        "imprisoned",
        "imprisonment",
        "impropriety",
        "imprudent",
        "impure",
        "impurity",
        "imputation",
        "inability",
        "inaccessible",
        "inaccurate",
        "inaction",
        "inactivity",
        "inadequacy",
        "inadequate",
        "inadmissible",
        "inane",
        "inapplicable",
        "inappropriate",
        "inattention",
        "inaudible",
        "incalculable",
        "incapacity",
        "incarceration",
        "incase",
        "incendiary",
        "incense",
        "incessant",
        "incest",
        "incestuous",
        "incineration",
        "incite",
        "inclement",
        "incoherent",
        "incompatible",
        "incompetence",
        "incompetent",
        "incompleteness",
        "incomprehensible",
        "incongruous",
        "inconsequential",
        "inconsiderate",
        "inconsistency",
        "inconvenient",
        "incorrect",
        "incredulous",
        "incrimination",
        "incubus",
        "incur",
        "incurable",
        "incursion",
        "indecent",
        "indecision",
        "indecisive",
        "indefensible",
        "indemnify",
        "indenture",
        "indeterminate",
        "indict",
        "indictment",
        "indifference",
        "indigent",
        "indignant",
        "indignation",
        "indistinct",
        "indoctrination",
        "indolent",
        "ineffective",
        "ineffectual",
        "inefficiency",
        "inefficient",
        "inept",
        "ineptitude",
        "inequality",
        "inequitable",
        "inert",
        "inexcusable",
        "inexperience",
        "inexperienced",
        "inexplicable",
        "infamous",
        "infamy",
        "infanticide",
        "infantile",
        "infarct",
        "infect",
        "infection",
        "infectious",
        "inferior",
        "inferiority",
        "inferno",
        "infertility",
        "infestation",
        "infidel",
        "infidelity",
        "infirm",
        "infirmity",
        "inflammation",
        "inflated",
        "inflation",
        "inflict",
        "infliction",
        "influenza",
        "informer",
        "infraction",
        "infrequently",
        "infringement",
        "inhibit",
        "inhospitable",
        "inhuman",
        "inhumanity",
        "inimical",
        "iniquity",
        "injunction",
        "injure",
        "injured",
        "injurious",
        "injury",
        "injustice",
        "inmate",
        "inoperative",
        "insane",
        "insanity",
        "insecure",
        "insecurity",
        "insidious",
        "insignificance",
        "insignificant",
        "insipid",
        "insolent",
        "insolvency",
        "insolvent",
        "instability",
        "instigate",
        "instigation",
        "insufficiency",
        "insufficient",
        "insufficiently",
        "insult",
        "insulting",
        "insurgent",
        "insurmountable",
        "insurrection",
        "inter",
        "interdiction",
        "interference",
        "interment",
        "interrupt",
        "interrupted",
        "intestate",
        "intimidate",
        "intimidation",
        "intolerable",
        "intolerance",
        "intolerant",
        "intoxicated",
        "intractable",
        "intrigue",
        "intruder",
        "intrusion",
        "intrusive",
        "invade",
        "invader",
        "invalidate",
        "invalidation",
        "invalidity",
        "invasion",
        "involuntary",
        "involution",
        "irate",
        "ire",
        "irons",
        "irrational",
        "irrationality",
        "irreconcilable",
        "irregular",
        "irregularity",
        "irrelevant",
        "irreparable",
        "irresponsible",
        "irreverent",
        "irrevocable",
        "irritability",
        "irritable",
        "irritating",
        "irritation",
        "isolated",
        "isolation",
        "jabber",
        "jail",
        "jargon",
        "jarring",
        "jaundice",
        "jealous",
        "jealousy",
        "jeopardize",
        "jeopardy",
        "john",
        "joke",
        "jornada",
        "jumble",
        "junk",
        "junta",
        "juvenile",
        "kern",
        "kick",
        "kidnap",
        "kill",
        "killing",
        "kite",
        "knell",
        "knotted",
        "labored",
        "laborious",
        "labyrinth",
        "lack",
        "lacking",
        "lackluster",
        "laden",
        "lag",
        "lagging",
        "lair",
        "lament",
        "landslide",
        "languid",
        "languish",
        "languishing",
        "lapse",
        "larceny",
        "lash",
        "late",
        "lateness",
        "latent",
        "latrines",
        "laughable",
        "lava",
        "lawlessness",
        "lawsuit",
        "lawyer",
        "lax",
        "laxative",
        "lazy",
        "leak",
        "leakage",
        "leaky",
        "leave",
        "leech",
        "leeches",
        "leer",
        "lemon",
        "leprosy",
        "lesbian",
        "lessen",
        "lesser",
        "lethal",
        "lethargy",
        "leukemia",
        "levy",
        "lewd",
        "liaison",
        "liar",
        "libel",
        "lick",
        "lie",
        "lifeless",
        "limited",
        "limp",
        "lint",
        "liquor",
        "listless",
        "litigant",
        "litigate",
        "litigation",
        "litigious",
        "litter",
        "livid",
        "loaf",
        "loafer",
        "loath",
        "loathe",
        "loathing",
        "loathsome",
        "lobbyist",
        "lockup",
        "locust",
        "lofty",
        "loneliness",
        "lonely",
        "lonesome",
        "loo",
        "loom",
        "loon",
        "loony",
        "loot",
        "lose",
        "losing",
        "loss",
        "lost",
        "loudness",
        "lounge",
        "louse",
        "lower",
        "lowering",
        "lowest",
        "lowlands",
        "lowly",
        "ludicrous",
        "lumbering",
        "lump",
        "lumpy",
        "lunacy",
        "lunatic",
        "lurch",
        "lure",
        "lurid",
        "lurk",
        "lurking",
        "lush",
        "lust",
        "lustful",
        "lying",
        "lynch",
        "mace",
        "mad",
        "madden",
        "madman",
        "madness",
        "mafia",
        "maggot",
        "makeshift",
        "malady",
        "malaise",
        "malaria",
        "malevolent",
        "malfeasance",
        "malformation",
        "malice",
        "malicious",
        "malign",
        "malignancy",
        "malignant",
        "malpractice",
        "mandamus",
        "mange",
        "mangle",
        "mania",
        "maniac",
        "maniacal",
        "manipulate",
        "manipulation",
        "manslaughter",
        "manure",
        "mar",
        "margin",
        "maroon",
        "martingale",
        "martyr",
        "martyrdom",
        "masochism",
        "massacre",
        "materialism",
        "materialist",
        "meandering",
        "meaningless",
        "measles",
        "meddle",
        "mediocre",
        "mediocrity",
        "melancholic",
        "melancholy",
        "melee",
        "melodrama",
        "meltdown",
        "menace",
        "menacing",
        "menial",
        "mercenary",
        "merciless",
        "mess",
        "messy",
        "metastasis",
        "methanol",
        "mildew",
        "militia",
        "mimicry",
        "minimize",
        "minimum",
        "minority",
        "mire",
        "misbehavior",
        "miscarriage",
        "mischief",
        "mischievous",
        "misconception",
        "misconduct",
        "miserable",
        "miserably",
        "misery",
        "misfortune",
        "misguided",
        "mishap",
        "misinterpretation",
        "mislead",
        "misleading",
        "mismanagement",
        "mismatch",
        "misnomer",
        "misplace",
        "misplaced",
        "misrepresent",
        "misrepresentation",
        "misrepresented",
        "missing",
        "misstatement",
        "mistake",
        "mistaken",
        "mistress",
        "mistrust",
        "misunderstand",
        "misunderstanding",
        "misuse",
        "mite",
        "mob",
        "mockery",
        "mocking",
        "molestation",
        "monochrome",
        "monopolist",
        "monsoon",
        "monster",
        "monstrosity",
        "moody",
        "moot",
        "morbid",
        "morbidity",
        "morgue",
        "moribund",
        "moron",
        "moronic",
        "morsel",
        "mortal",
        "mortality",
        "mortification",
        "mortuary",
        "mosquito",
        "mourn",
        "mournful",
        "mourning",
        "muck",
        "mud",
        "muddle",
        "muddled",
        "muddy",
        "muff",
        "mule",
        "mum",
        "mumble",
        "mumps",
        "murder",
        "murderer",
        "murderous",
        "murky",
        "muss",
        "musty",
        "mutant",
        "mutilated",
        "mutilation",
        "mutiny",
        "mutter",
        "muzzle",
        "myopia",
        "nab",
        "nadir",
        "nag",
        "naive",
        "nameless",
        "nappy",
        "narcotic",
        "nasty",
        "naughty",
        "nausea",
        "nauseous",
        "nay",
        "needful",
        "needy",
        "nefarious",
        "negation",
        "negative",
        "neglect",
        "neglected",
        "neglecting",
        "negligence",
        "negligent",
        "negligently",
        "negro",
        "nepotism",
        "nervous",
        "nether",
        "nettle",
        "neuralgia",
        "neurosis",
        "neurotic",
        "nicotine",
        "nigger",
        "nightmare",
        "nihilism",
        "noise",
        "noisy",
        "noncompliance",
        "nonsense",
        "nonsensical",
        "noose",
        "nothingness",
        "noxious",
        "nuisance",
        "nul",
        "nullify",
        "numb",
        "numbness",
        "nun",
        "oaf",
        "obese",
        "obesity",
        "obi",
        "obit",
        "obituary",
        "objection",
        "objectionable",
        "oblige",
        "obligor",
        "obliterate",
        "obliterated",
        "obliteration",
        "oblivion",
        "obnoxious",
        "obscene",
        "obscenity",
        "obscurity",
        "obstacle",
        "obstinate",
        "obstruct",
        "obstruction",
        "obstructive",
        "obtuse",
        "occult",
        "oddity",
        "odious",
        "odor",
        "offend",
        "offended",
        "offender",
        "offense",
        "offensive",
        "offhand",
        "offing",
        "ogre",
        "olfactory",
        "oligarchy",
        "omen",
        "ominous",
        "omit",
        "onerous",
        "onus",
        "ooze",
        "opaque",
        "operatic",
        "opiate",
        "opinionated",
        "opium",
        "opponent",
        "oppose",
        "opposed",
        "opposition",
        "oppress",
        "oppression",
        "oppressive",
        "oppressor",
        "orc",
        "ordeal",
        "ordnance",
        "orphan",
        "ostensibly",
        "oust",
        "outcast",
        "outcry",
        "outhouse",
        "outlandish",
        "outlaw",
        "outrage",
        "ovation",
        "overbearing",
        "overburden",
        "overcast",
        "overdo",
        "overdose",
        "overdue",
        "overestimated",
        "overflow",
        "overgrown",
        "overload",
        "overpaid",
        "overpower",
        "overpowering",
        "overpriced",
        "oversight",
        "overthrow",
        "overturn",
        "overwhelm",
        "overwhelmed",
        "owing",
        "oxidation",
        "pain",
        "pained",
        "painful",
        "painfully",
        "pains",
        "palsy",
        "pandemic",
        "pang",
        "panic",
        "paralysis",
        "paralyzed",
        "paranoia",
        "parasite",
        "pare",
        "parrot",
        "parsimonious",
        "partisan",
        "passe",
        "passive",
        "passivity",
        "patch",
        "pathetic",
        "patronizing",
        "patter",
        "paucity",
        "pauper",
        "pawn",
        "payback",
        "payment",
        "peculiarities",
        "pedestrian",
        "penal",
        "penalty",
        "penetration",
        "penitentiary",
        "perdition",
        "peril",
        "perilous",
        "perish",
        "perishable",
        "perished",
        "perishing",
        "perjury",
        "pernicious",
        "perpetrator",
        "perpetuation",
        "perplexed",
        "perplexity",
        "persecute",
        "persecution",
        "perturbation",
        "pertussis",
        "perverse",
        "perversion",
        "pervert",
        "perverted",
        "pessimism",
        "pessimist",
        "pest",
        "pestilence",
        "pet",
        "petty",
        "phantom",
        "phlegm",
        "phony",
        "picket",
        "picketing",
        "pickle",
        "pig",
        "pigeon",
        "piles",
        "pillage",
        "pimp",
        "pimple",
        "pine",
        "pinion",
        "pique",
        "piracy",
        "pirate",
        "pistol",
        "pitfall",
        "plagiarism",
        "plague",
        "plaintiff",
        "plated",
        "player",
        "plea",
        "plight",
        "plodding",
        "plummet",
        "plunder",
        "plunge",
        "pneumonia",
        "poaching",
        "pointless",
        "poison",
        "poisoned",
        "poisoning",
        "poisonous",
        "poke",
        "polemic",
        "polio",
        "pollute",
        "pollution",
        "polygamy",
        "pomp",
        "pompous",
        "ponderous",
        "poorly",
        "pop",
        "porcupine",
        "porn",
        "porno",
        "pornographic",
        "pornography",
        "pose",
        "possessed",
        "possession",
        "posthumous",
        "postponement",
        "pound",
        "poverty",
        "powerless",
        "prank",
        "precarious",
        "precinct",
        "predatory",
        "predicament",
        "pregnancy",
        "prejudice",
        "prejudiced",
        "prejudicial",
        "premeditated",
        "pressure",
        "presumptuous",
        "pretend",
        "pretended",
        "pretending",
        "pretense",
        "pretensions",
        "preventive",
        "prey",
        "prick",
        "prickly",
        "prison",
        "prisoner",
        "privy",
        "problem",
        "procrastinate",
        "procrastination",
        "profane",
        "profanity",
        "profusion",
        "prohibited",
        "prohibition",
        "prolong",
        "promiscuous",
        "propaganda",
        "prosecute",
        "prosecution",
        "prostitute",
        "prostitution",
        "provocation",
        "provoking",
        "pry",
        "prying",
        "psychosis",
        "publicist",
        "puffy",
        "punch",
        "pungent",
        "punish",
        "punished",
        "punishing",
        "punishment",
        "punitive",
        "purgatory",
        "purge",
        "pus",
        "quack",
        "quagmire",
        "quail",
        "quandary",
        "quarrel",
        "quash",
        "quell",
        "questionable",
        "quicksilver",
        "quit",
        "quiver",
        "quivering",
        "quiz",
        "rabble",
        "rabid",
        "rabies",
        "rack",
        "racket",
        "radiation",
        "radioactive",
        "radon",
        "rage",
        "raging",
        "rags",
        "raid",
        "rail",
        "ram",
        "rambling",
        "rampage",
        "rancid",
        "ransom",
        "rape",
        "raptors",
        "rascal",
        "rash",
        "rat",
        "rating",
        "raucous",
        "ravenous",
        "raving",
        "reactionary",
        "rear",
        "rebel",
        "rebuke",
        "rebut",
        "recalcitrant",
        "recession",
        "recidivism",
        "reckless",
        "recklessness",
        "redundant",
        "reflux",
        "refractory",
        "refusal",
        "refuse",
        "refused",
        "regress",
        "regression",
        "regret",
        "regrettable",
        "regretted",
        "regretting",
        "regulatory",
        "rein",
        "reject",
        "rejected",
        "rejection",
        "rejects",
        "relapse",
        "relegation",
        "relinquish",
        "reluctant",
        "remand",
        "remedial",
        "remiss",
        "remorse",
        "removal",
        "remove",
        "rencontre",
        "rend",
        "renegade",
        "renounce",
        "renunciation",
        "repellant",
        "repellent",
        "repelling",
        "repress",
        "repression",
        "reprimand",
        "reprint",
        "reprisal",
        "reproach",
        "republic",
        "repudiation",
        "repulsion",
        "rescind",
        "rescission",
        "resent",
        "resentful",
        "resentment",
        "resign",
        "resignation",
        "resigned",
        "resist",
        "resistance",
        "resistant",
        "resisting",
        "restrain",
        "restrict",
        "restriction",
        "restrictive",
        "retaliate",
        "retaliation",
        "retaliatory",
        "retard",
        "retardation",
        "reticent",
        "retort",
        "retract",
        "retraction",
        "retrenchment",
        "retribution",
        "retrograde",
        "revenge",
        "reversal",
        "revocation",
        "revoke",
        "revolt",
        "revolting",
        "revolver",
        "revulsion",
        "rheumatism",
        "rickety",
        "riddled",
        "ridicule",
        "ridiculous",
        "rife",
        "rifle",
        "rift",
        "rigid",
        "rigidity",
        "rigor",
        "rigorous",
        "ringer",
        "riot",
        "riotous",
        "risk",
        "risky",
        "rivalry",
        "rob",
        "robber",
        "robbery",
        "rogue",
        "rook",
        "rot",
        "rotting",
        "roughness",
        "rout",
        "row",
        "rowdy",
        "rubbish",
        "rubble",
        "rue",
        "ruffle",
        "rugged",
        "ruin",
        "ruined",
        "ruinous",
        "rumor",
        "runaway",
        "rupture",
        "ruse",
        "rust",
        "rusty",
        "ruthless",
        "saber",
        "sabotage",
        "sacrifices",
        "sadly",
        "sadness",
        "sag",
        "sap",
        "sarcasm",
        "sarcoma",
        "sardonic",
        "satanic",
        "saturated",
        "savage",
        "savagery",
        "scab",
        "scaffold",
        "scalpel",
        "scaly",
        "scandal",
        "scandalous",
        "scanty",
        "scapegoat",
        "scar",
        "scarce",
        "scarcely",
        "scarcity",
        "scare",
        "scavenger",
        "scheme",
        "schism",
        "schizophrenia",
        "sciatica",
        "scoff",
        "scold",
        "scolding",
        "scorching",
        "scorn",
        "scorpion",
        "scotch",
        "scoundrel",
        "scourge",
        "scrambling",
        "scrapie",
        "scream",
        "screaming",
        "screech",
        "screwed",
        "scrimmage",
        "scrub",
        "scrutinize",
        "scrutiny",
        "scum",
        "sear",
        "secession",
        "secluded",
        "secondhand",
        "secretion",
        "secretive",
        "sectarian",
        "sedition",
        "seduce",
        "seduction",
        "segregate",
        "segregated",
        "seize",
        "selfish",
        "selfishness",
        "senile",
        "senseless",
        "sentence",
        "separatist",
        "sepsis",
        "septic",
        "sequestration",
        "serene",
        "serpent",
        "servant",
        "serve",
        "servile",
        "servitude",
        "setback",
        "sever",
        "sewage",
        "sewerage",
        "shabby",
        "shack",
        "shackle",
        "shady",
        "shaking",
        "shaky",
        "sham",
        "shambles",
        "shame",
        "shameful",
        "shameless",
        "shanghai",
        "shark",
        "shatter",
        "shattered",
        "shed",
        "shell",
        "shelved",
        "shipwreck",
        "shit",
        "shiver",
        "shock",
        "shoddy",
        "shoot",
        "shooting",
        "shoplifting",
        "shortage",
        "shortcoming",
        "shot",
        "shove",
        "showy",
        "shriek",
        "shrill",
        "shrink",
        "shrunk",
        "shudder",
        "shun",
        "sick",
        "sickening",
        "sickly",
        "sickness",
        "silly",
        "sin",
        "sinful",
        "sinister",
        "sinner",
        "sinning",
        "siren",
        "sissy",
        "skeptical",
        "sketchy",
        "skewed",
        "skid",
        "skip",
        "skirmish",
        "slack",
        "slag",
        "slam",
        "slander",
        "slanderous",
        "slap",
        "slaughter",
        "slaughterhouse",
        "slaughtering",
        "slave",
        "slavery",
        "slay",
        "slayer",
        "sleet",
        "slimy",
        "slink",
        "slip",
        "slop",
        "sloppy",
        "sloth",
        "slouch",
        "slough",
        "slowness",
        "sludge",
        "slug",
        "sluggish",
        "slum",
        "slump",
        "slur",
        "slush",
        "slut",
        "sly",
        "smack",
        "small",
        "smash",
        "smashed",
        "smattering",
        "smell",
        "smelling",
        "smirk",
        "smite",
        "smoker",
        "smother",
        "smudge",
        "smug",
        "smuggle",
        "smuggler",
        "smuggling",
        "smut",
        "snag",
        "snags",
        "snake",
        "snare",
        "snarl",
        "snarling",
        "sneak",
        "sneaking",
        "sneer",
        "sneeze",
        "snide",
        "snob",
        "soak",
        "sob",
        "socialist",
        "soil",
        "soiled",
        "somatic",
        "somber",
        "soot",
        "sorcery",
        "sordid",
        "sore",
        "sorely",
        "soreness",
        "sorrow",
        "sorrowful",
        "sortie",
        "soulless",
        "soulmate",
        "sour",
        "spank",
        "spasm",
        "spat",
        "spear",
        "speck",
        "specter",
        "spectral",
        "speculation",
        "spent",
        "spinster",
        "spite",
        "spiteful",
        "splinter",
        "split",
        "splitting",
        "spoil",
        "spoiler",
        "spoke",
        "sponge",
        "spook",
        "sprain",
        "spree",
        "sprite",
        "spurious",
        "squall",
        "squatter",
        "squeamish",
        "squelch",
        "squirm",
        "stab",
        "staggering",
        "stagnant",
        "stain",
        "stale",
        "stalk",
        "standoff",
        "standstill",
        "staring",
        "stark",
        "startle",
        "starvation",
        "starved",
        "starving",
        "stationary",
        "stave",
        "steal",
        "stealing",
        "stealthy",
        "stereotype",
        "stereotyped",
        "sterile",
        "sterility",
        "stern",
        "stiff",
        "stiffness",
        "stifle",
        "stifled",
        "stigma",
        "stillborn",
        "sting",
        "stinging",
        "stingy",
        "stink",
        "stinking",
        "stint",
        "stocks",
        "stolen",
        "stone",
        "stoned",
        "stools",
        "stoppage",
        "storm",
        "stormy",
        "strained",
        "straits",
        "stranded",
        "stranger",
        "strangle",
        "stray",
        "stress",
        "strife",
        "strike",
        "strip",
        "stripe",
        "stripped",
        "stroke",
        "struggle",
        "strut",
        "stuffy",
        "stumble",
        "stunned",
        "stunted",
        "stupid",
        "stupidity",
        "stupor",
        "sty",
        "subdue",
        "subject",
        "subjected",
        "subjection",
        "subjugation",
        "subordinate",
        "subpoena",
        "subsidence",
        "subsidy",
        "subsist",
        "subtract",
        "subversion",
        "subversive",
        "subvert",
        "succumb",
        "suck",
        "sucker",
        "sue",
        "suffer",
        "sufferer",
        "suffering",
        "suffocating",
        "suffocation",
        "suicidal",
        "suicide",
        "sullen",
        "summons",
        "sunk",
        "superficial",
        "superfluous",
        "superstitious",
        "suppress",
        "suppression",
        "surcharge",
        "surly",
        "surrender",
        "surrendering",
        "susceptible",
        "suspect",
        "suspension",
        "suspicion",
        "suspicious",
        "swab",
        "swamp",
        "swampy",
        "swastika",
        "swelling",
        "swig",
        "swine",
        "swollen",
        "symptom",
        "syncope",
        "taboo",
        "taint",
        "talons",
        "tangled",
        "tardiness",
        "tardy",
        "tariff",
        "tarnish",
        "tarry",
        "tasteless",
        "taunt",
        "tax",
        "tease",
        "teasing",
        "tedious",
        "tedium",
        "tempest",
        "temptation",
        "tenement",
        "terminal",
        "termination",
        "termite",
        "terrible",
        "terror",
        "terrorism",
        "terrorist",
        "terrorize",
        "tetanus",
        "tether",
        "theft",
        "theism",
        "theocratic",
        "thief",
        "thirsty",
        "thorn",
        "thorny",
        "thoughtless",
        "thrash",
        "threat",
        "threaten",
        "threatening",
        "thresh",
        "throb",
        "throttle",
        "thug",
        "thump",
        "thundering",
        "thwart",
        "tiff",
        "timid",
        "timidity",
        "tipsy",
        "tirade",
        "tired",
        "tiredness",
        "tiresome",
        "tit",
        "toad",
        "tobacco",
        "toilet",
        "toils",
        "tolerate",
        "toothache",
        "torment",
        "torn",
        "torpedo",
        "torrid",
        "tort",
        "tortious",
        "torture",
        "touched",
        "touchy",
        "tough",
        "toxic",
        "toxin",
        "tragedy",
        "tragic",
        "traitor",
        "tramp",
        "trance",
        "transgression",
        "trappings",
        "traps",
        "trash",
        "trashy",
        "traumatic",
        "travail",
        "travesty",
        "treacherous",
        "treachery",
        "treason",
        "trembling",
        "tremor",
        "trepidation",
        "trespass",
        "tribulation",
        "tribunal",
        "trick",
        "trickery",
        "trifle",
        "tripping",
        "troll",
        "troublesome",
        "trumpet",
        "tumble",
        "tumor",
        "tumour",
        "tumult",
        "tumultuous",
        "turbulence",
        "turbulent",
        "turmoil",
        "twitch",
        "typhoon",
        "tyrannical",
        "tyranny",
        "tyrant",
        "ugliness",
        "ugly",
        "ulcer",
        "ulterior",
        "ultimatum",
        "unable",
        "unacceptable",
        "unaccountable",
        "unapproved",
        "unattached",
        "unattainable",
        "unattractive",
        "unauthorized",
        "unavoidable",
        "unaware",
        "unbearable",
        "unbelief",
        "unbelievable",
        "unborn",
        "uncanny",
        "uncaring",
        "uncertain",
        "unchangeable",
        "unclean",
        "uncomfortable",
        "unconscionable",
        "unconscious",
        "unconstitutional",
        "uncontrollable",
        "uncontrolled",
        "undecided",
        "undermined",
        "underpaid",
        "undersized",
        "undesirable",
        "undesired",
        "undo",
        "uneasiness",
        "uneasy",
        "uneducated",
        "unemployed",
        "unequal",
        "uneven",
        "unexplained",
        "unfair",
        "unfairness",
        "unfaithful",
        "unfavorable",
        "unfinished",
        "unforgiving",
        "unfortunate",
        "unfriendly",
        "unfulfilled",
        "unfurnished",
        "ungodly",
        "ungrateful",
        "unhappiness",
        "unhappy",
        "unhealthy",
        "unholy",
        "unimportant",
        "unimpressed",
        "unimproved",
        "uninformed",
        "uninitiated",
        "uninspired",
        "unintelligible",
        "unintentionally",
        "uninterested",
        "uninteresting",
        "unjust",
        "unjustifiable",
        "unjustified",
        "unkind",
        "unknown",
        "unlawful",
        "unlicensed",
        "unlucky",
        "unmanageable",
        "unnatural",
        "unofficial",
        "unpaid",
        "unpleasant",
        "unpopular",
        "unpredictable",
        "unprepared",
        "unproductive",
        "unprofitable",
        "unprotected",
        "unpublished",
        "unreliable",
        "unrequited",
        "unruly",
        "unsafe",
        "unsatisfactory",
        "unsatisfied",
        "unsavory",
        "unscrupulous",
        "unsettled",
        "unsightly",
        "unsophisticated",
        "unspeakable",
        "unstable",
        "unsuccessful",
        "unsuitable",
        "unsung",
        "unsupported",
        "unsustainable",
        "unsympathetic",
        "untamed",
        "untenable",
        "unthinkable",
        "untidy",
        "untimely",
        "untitled",
        "untold",
        "untoward",
        "untrained",
        "untrue",
        "untrustworthy",
        "unwarranted",
        "unwashed",
        "unwelcome",
        "unwell",
        "unwillingness",
        "unwise",
        "unwitting",
        "unworthy",
        "unyielding",
        "upheaval",
        "uprising",
        "uproar",
        "upset",
        "urchin",
        "urgent",
        "useless",
        "usurp",
        "usurped",
        "usury",
        "vacancy",
        "vacuous",
        "vague",
        "vagueness",
        "vainly",
        "vampire",
        "vanished",
        "vanity",
        "varicella",
        "varicose",
        "vegetative",
        "vehement",
        "vendetta",
        "vengeance",
        "vengeful",
        "venom",
        "venomous",
        "verbosity",
        "verge",
        "vermin",
        "versus",
        "vertigo",
        "veto",
        "vice",
        "vicious",
        "victim",
        "victimized",
        "villain",
        "villainous",
        "vindictive",
        "violation",
        "violence",
        "violent",
        "violently",
        "viper",
        "virulence",
        "virus",
        "visitation",
        "vixen",
        "volatility",
        "volcano",
        "vomiting",
        "voodoo",
        "vulgar",
        "vulgarity",
        "vulnerability",
        "vulture",
        "waffle",
        "wail",
        "wait",
        "wallow",
        "wan",
        "wane",
        "wanting",
        "war",
        "warden",
        "ware",
        "warfare",
        "warlike",
        "warn",
        "warp",
        "warped",
        "wart",
        "waste",
        "wasted",
        "wasteful",
        "wasting",
        "watery",
        "waver",
        "weakened",
        "weakly",
        "weakness",
        "wear",
        "wearily",
        "weariness",
        "weary",
        "weeds",
        "weep",
        "weird",
        "weirdo",
        "wen",
        "wench",
        "whack",
        "whim",
        "whine",
        "whip",
        "whirlwind",
        "whisky",
        "whore",
        "wicked",
        "wickedness",
        "wild",
        "wildcat",
        "wildfire",
        "willful",
        "wimp",
        "wimpy",
        "wince",
        "witch",
        "witchcraft",
        "withdraw",
        "wither",
        "withered",
        "woe",
        "woeful",
        "woefully",
        "words",
        "worm",
        "worn",
        "worried",
        "worry",
        "worrying",
        "worse",
        "worsening",
        "worthless",
        "wound",
        "wrangling",
        "wrath",
        "wreak",
        "wreck",
        "wrecked",
        "wrench",
        "wrestling",
        "wretch",
        "wretched",
        "wrong",
        "wrongdoing",
        "wrongful",
        "wrongly",
        "wrought",
        "wry",
        "xenophobia",
        "yawn",
        "yawning",
        "yell",
        "yellows",
        "yelp",
        "zip",
    ]
)

_ambivalent = set(
    [
        "abundance",
        "armed",
        "balm",
        "boast",
        "boisterous",
        "bookworm",
        "buck",
        "celebrity",
        "charmed",
        "circumvention",
        "complicity",
        "confess",
        "cunning",
        "dependent",
        "diverse",
        "dominate",
        "endless",
        "enforce",
        "erotic",
        "escape",
        "feeling",
        "flirt",
        "hail",
        "hedonism",
        "highest",
        "humble",
        "immediately",
        "immovable",
        "income",
        "infiltration",
        "influence",
        "intense",
        "interminable",
        "intervention",
        "lace",
        "liberal",
        "lord",
        "maternal",
        "midwife",
        "mother",
        "mug",
        "notoriety",
        "omnipotence",
        "outburst",
        "outstanding",
        "parade",
        "paraphrase",
        "petroleum",
        "presentment",
        "prodigal",
        "quote",
        "rave",
        "regressive",
        "rekindle",
        "remains",
        "retirement",
        "revive",
        "revolution",
        "scarecrow",
        "seclusion",
        "sensual",
        "spectacle",
        "spine",
        "sterling",
        "succulent",
        "superstition",
        "supremacy",
        "surround",
        "synonymous",
        "tantalizing",
        "teens",
        "treat",
        "unbeaten",
        "unbridled",
        "unexpected",
        "unimaginable",
        "untie",
        "uphill",
        "vote",
        "weight",
        "yearning",
    ]
)
